@@ -1,4 +1,4 @@
 __version__ = "2.1"
 __author__ = "Sergey039"
 
-from find_url.find import *
+from find_url.find_url import *
